.. Zenaton documentation master file, created by
   sphinx-quickstart on Tue Jun 27 12:21:55 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Zenaton's documentation!
===================================

.. toctree::
   :maxdepth: 1
   :caption: API Documentation:
   :glob:

   api/*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
